==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/base/data/src/test/java/org/openscience/cdk/ReactionSchemeTest.java <==
/* Copyright (C) 2007  Miguel Rojasch <miguelrojasch@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
package org.openscience.cdk;

import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import org.openscience.cdk.interfaces.IChemObject;
import org.openscience.cdk.interfaces.IReactionScheme;
import org.openscience.cdk.test.interfaces.AbstractReactionSchemeTest;
import org.openscience.cdk.test.interfaces.ITestObjectBuilder;

/**
 * Checks the functionality of the MolecularFormulaSet class.
 *
 * @cdk.module test-data
 *
 * @see ReactionScheme
 */
public class ReactionSchemeTest extends AbstractReactionSchemeTest {

    @BeforeClass
    public static void setUp() {
        setTestObjectBuilder(new ITestObjectBuilder() {

            @Override
            public IChemObject newTestObject() {
                return new ReactionScheme();
            }
        });
    }

    /**
     * A unit test suite for JUnit.
     *
     *
     */
    @Test
    public void testReactionScheme() {
        IReactionScheme scheme = new ReactionScheme();
        Assert.assertNotNull(scheme);
    }

}

==> cdk_2.11.orig.tar.gz: cdk-cdk-2.11/base/data/src/test/java/org/openscience/cdk/ReactionSchemeTest.java <==
/* Copyright (C) 2007  Miguel Rojasch <miguelrojasch@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
package org.openscience.cdk;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.openscience.cdk.interfaces.IReactionScheme;
import org.openscience.cdk.test.interfaces.AbstractReactionSchemeTest;

/**
 * Checks the functionality of the MolecularFormulaSet class.
 *
 *
 * @see ReactionScheme
 */
class ReactionSchemeTest extends AbstractReactionSchemeTest {

    @BeforeAll
    static void setUp() {
        setTestObjectBuilder(ReactionScheme::new);
    }

    /**
     * A unit test suite for JUnit.
     *
     *
     */
    @Test
    void testReactionScheme() {
        IReactionScheme scheme = new ReactionScheme();
        Assertions.assertNotNull(scheme);
    }

}
